@@ -4,20 +4,20 @@
 // Version defines
 #define WT_SERIES 3
 #define WT_MAJOR  3
-#define WT_MINOR  5
+#define WT_MINOR  8
 
 /*! \brief A constant that encodes the library version of %Wt
  *
  * You may use this constant to check for the version of %Wt at build-time.
  */
 #define WT_VERSION (((WT_SERIES & 0xff) << 24) | ((WT_MAJOR & 0xff) << 16) | ((WT_MINOR & 0xff) << 8))
-#define WT_VERSION_STR "3.3.5"
-#define WT_CLASS       "Wt3_3_5"
-#define WT_INCLUDED_VERSION Wt_3_3_5
+#define WT_VERSION_STR "3.3.8"
+#define WT_CLASS       "Wt3_3_8"
+#define WT_INCLUDED_VERSION Wt_3_3_8
 
 #define RUNDIR "/var/run/wt"
-#define WT_CONFIG_XML "/etc/wt_config.xml"
-#define WTHTTP_CONFIGURATION "/etc/wthttpd"
+#define WT_CONFIG_XML "/etc/wt/wt_config.xml"
+#define WTHTTP_CONFIGURATION "/etc/wt/wthttpd"
 
 
 /* #undef WT_STATIC */
